==> cdktf-provider-google-2.0.22-sources.jar: com/hashicorp/cdktf/providers/google/ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties.java <==
package com.hashicorp.cdktf.providers.google;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-12T00:46:05.233Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties")
@software.amazon.jsii.Jsii.Proxy(ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties extends software.amazon.jsii.JsiiSerializable {

    /**
     * Whether to perform a 'guest aware' snapshot.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_resource_policy#guest_flush ComputeResourcePolicy#guest_flush}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getGuestFlush() {
        return null;
    }

    /**
     * A set of key-value pairs.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_resource_policy#labels ComputeResourcePolicy#labels}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.lang.String> getLabels() {
        return null;
    }

    /**
     * Cloud Storage bucket location to store the auto snapshot (regional or multi-regional).
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_resource_policy#storage_locations ComputeResourcePolicy#storage_locations}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getStorageLocations() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties> {
        java.lang.Object guestFlush;
        java.util.Map<java.lang.String, java.lang.String> labels;
        java.util.List<java.lang.String> storageLocations;

        /**
         * Sets the value of {@link ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties#getGuestFlush}
         * @param guestFlush Whether to perform a 'guest aware' snapshot.
         *                   Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_resource_policy#guest_flush ComputeResourcePolicy#guest_flush}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder guestFlush(java.lang.Boolean guestFlush) {
            this.guestFlush = guestFlush;
            return this;
        }

        /**
         * Sets the value of {@link ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties#getGuestFlush}
         * @param guestFlush Whether to perform a 'guest aware' snapshot.
         *                   Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_resource_policy#guest_flush ComputeResourcePolicy#guest_flush}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder guestFlush(com.hashicorp.cdktf.IResolvable guestFlush) {
            this.guestFlush = guestFlush;
            return this;
        }

        /**
         * Sets the value of {@link ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties#getLabels}
         * @param labels A set of key-value pairs.
         *               Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_resource_policy#labels ComputeResourcePolicy#labels}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder labels(java.util.Map<java.lang.String, java.lang.String> labels) {
            this.labels = labels;
            return this;
        }

        /**
         * Sets the value of {@link ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties#getStorageLocations}
         * @param storageLocations Cloud Storage bucket location to store the auto snapshot (regional or multi-regional).
         *                         Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_resource_policy#storage_locations ComputeResourcePolicy#storage_locations}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder storageLocations(java.util.List<java.lang.String> storageLocations) {
            this.storageLocations = storageLocations;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties {
        private final java.lang.Object guestFlush;
        private final java.util.Map<java.lang.String, java.lang.String> labels;
        private final java.util.List<java.lang.String> storageLocations;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.guestFlush = software.amazon.jsii.Kernel.get(this, "guestFlush", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.labels = software.amazon.jsii.Kernel.get(this, "labels", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.storageLocations = software.amazon.jsii.Kernel.get(this, "storageLocations", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.guestFlush = builder.guestFlush;
            this.labels = builder.labels;
            this.storageLocations = builder.storageLocations;
        }

        @Override
        public final java.lang.Object getGuestFlush() {
            return this.guestFlush;
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.String> getLabels() {
            return this.labels;
        }

        @Override
        public final java.util.List<java.lang.String> getStorageLocations() {
            return this.storageLocations;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getGuestFlush() != null) {
                data.set("guestFlush", om.valueToTree(this.getGuestFlush()));
            }
            if (this.getLabels() != null) {
                data.set("labels", om.valueToTree(this.getLabels()));
            }
            if (this.getStorageLocations() != null) {
                data.set("storageLocations", om.valueToTree(this.getStorageLocations()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties.Jsii$Proxy that = (ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties.Jsii$Proxy) o;

            if (this.guestFlush != null ? !this.guestFlush.equals(that.guestFlush) : that.guestFlush != null) return false;
            if (this.labels != null ? !this.labels.equals(that.labels) : that.labels != null) return false;
            return this.storageLocations != null ? this.storageLocations.equals(that.storageLocations) : that.storageLocations == null;
        }

        @Override
        public final int hashCode() {
            int result = this.guestFlush != null ? this.guestFlush.hashCode() : 0;
            result = 31 * result + (this.labels != null ? this.labels.hashCode() : 0);
            result = 31 * result + (this.storageLocations != null ? this.storageLocations.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-google-2.0.46-sources.jar: com/hashicorp/cdktf/providers/google/ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties.java <==
package com.hashicorp.cdktf.providers.google;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-03T00:49:21.749Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties")
@software.amazon.jsii.Jsii.Proxy(ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties extends software.amazon.jsii.JsiiSerializable {

    /**
     * Creates the new snapshot in the snapshot chain labeled with the  specified name.
     * <p>
     * The chain name must be 1-63 characters long and comply
     * with RFC1035.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_resource_policy#chain_name ComputeResourcePolicy#chain_name}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getChainName() {
        return null;
    }

    /**
     * Whether to perform a 'guest aware' snapshot.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_resource_policy#guest_flush ComputeResourcePolicy#guest_flush}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getGuestFlush() {
        return null;
    }

    /**
     * A set of key-value pairs.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_resource_policy#labels ComputeResourcePolicy#labels}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.lang.String> getLabels() {
        return null;
    }

    /**
     * Cloud Storage bucket location to store the auto snapshot (regional or multi-regional).
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_resource_policy#storage_locations ComputeResourcePolicy#storage_locations}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getStorageLocations() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties> {
        java.lang.String chainName;
        java.lang.Object guestFlush;
        java.util.Map<java.lang.String, java.lang.String> labels;
        java.util.List<java.lang.String> storageLocations;

        /**
         * Sets the value of {@link ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties#getChainName}
         * @param chainName Creates the new snapshot in the snapshot chain labeled with the  specified name.
         *                  The chain name must be 1-63 characters long and comply
         *                  with RFC1035.
         *                  <p>
         *                  Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_resource_policy#chain_name ComputeResourcePolicy#chain_name}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder chainName(java.lang.String chainName) {
            this.chainName = chainName;
            return this;
        }

        /**
         * Sets the value of {@link ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties#getGuestFlush}
         * @param guestFlush Whether to perform a 'guest aware' snapshot.
         *                   Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_resource_policy#guest_flush ComputeResourcePolicy#guest_flush}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder guestFlush(java.lang.Boolean guestFlush) {
            this.guestFlush = guestFlush;
            return this;
        }

        /**
         * Sets the value of {@link ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties#getGuestFlush}
         * @param guestFlush Whether to perform a 'guest aware' snapshot.
         *                   Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_resource_policy#guest_flush ComputeResourcePolicy#guest_flush}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder guestFlush(com.hashicorp.cdktf.IResolvable guestFlush) {
            this.guestFlush = guestFlush;
            return this;
        }

        /**
         * Sets the value of {@link ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties#getLabels}
         * @param labels A set of key-value pairs.
         *               Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_resource_policy#labels ComputeResourcePolicy#labels}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder labels(java.util.Map<java.lang.String, java.lang.String> labels) {
            this.labels = labels;
            return this;
        }

        /**
         * Sets the value of {@link ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties#getStorageLocations}
         * @param storageLocations Cloud Storage bucket location to store the auto snapshot (regional or multi-regional).
         *                         Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_resource_policy#storage_locations ComputeResourcePolicy#storage_locations}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder storageLocations(java.util.List<java.lang.String> storageLocations) {
            this.storageLocations = storageLocations;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties {
        private final java.lang.String chainName;
        private final java.lang.Object guestFlush;
        private final java.util.Map<java.lang.String, java.lang.String> labels;
        private final java.util.List<java.lang.String> storageLocations;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.chainName = software.amazon.jsii.Kernel.get(this, "chainName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.guestFlush = software.amazon.jsii.Kernel.get(this, "guestFlush", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.labels = software.amazon.jsii.Kernel.get(this, "labels", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.storageLocations = software.amazon.jsii.Kernel.get(this, "storageLocations", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.chainName = builder.chainName;
            this.guestFlush = builder.guestFlush;
            this.labels = builder.labels;
            this.storageLocations = builder.storageLocations;
        }

        @Override
        public final java.lang.String getChainName() {
            return this.chainName;
        }

        @Override
        public final java.lang.Object getGuestFlush() {
            return this.guestFlush;
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.String> getLabels() {
            return this.labels;
        }

        @Override
        public final java.util.List<java.lang.String> getStorageLocations() {
            return this.storageLocations;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getChainName() != null) {
                data.set("chainName", om.valueToTree(this.getChainName()));
            }
            if (this.getGuestFlush() != null) {
                data.set("guestFlush", om.valueToTree(this.getGuestFlush()));
            }
            if (this.getLabels() != null) {
                data.set("labels", om.valueToTree(this.getLabels()));
            }
            if (this.getStorageLocations() != null) {
                data.set("storageLocations", om.valueToTree(this.getStorageLocations()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties.Jsii$Proxy that = (ComputeResourcePolicySnapshotSchedulePolicySnapshotProperties.Jsii$Proxy) o;

            if (this.chainName != null ? !this.chainName.equals(that.chainName) : that.chainName != null) return false;
            if (this.guestFlush != null ? !this.guestFlush.equals(that.guestFlush) : that.guestFlush != null) return false;
            if (this.labels != null ? !this.labels.equals(that.labels) : that.labels != null) return false;
            return this.storageLocations != null ? this.storageLocations.equals(that.storageLocations) : that.storageLocations == null;
        }

        @Override
        public final int hashCode() {
            int result = this.chainName != null ? this.chainName.hashCode() : 0;
            result = 31 * result + (this.guestFlush != null ? this.guestFlush.hashCode() : 0);
            result = 31 * result + (this.labels != null ? this.labels.hashCode() : 0);
            result = 31 * result + (this.storageLocations != null ? this.storageLocations.hashCode() : 0);
            return result;
        }
    }
}
